
# Materializer Methods

::: fliq.query.Query
    options:
        filters: [
            "^__contains__$", "^_group_by$", "^_validate_partition_index$", "^aggregate$", "^all$", "^any$", "^contains$", "^count$", "^equals$", "^first$", "^first_or_default$", "^max$", "^min$", "^sample$", "^single$", "^single_or_default$", "^sum$", "^to_dict$", "^to_list$" 
        ]   
